//+------------------------------------------------------------------+
//|                                                          SR.mq4 |
//|                               Copyright  2010, Yury V. Reshetov |
//|                               http://bigfx.ru/                   |
//+------------------------------------------------------------------+
#property copyright "Copyright  2010, Yury V. Reshetov"
#property link      "http://bigfx.ru/"

//---- input parameters
extern int          x11 = 100;
extern int          x21 = 100;
extern int          x31 = 100;
extern int          x41 = 100;
extern int          x12 = 100;
extern int          x22 = 100;
extern int          x32 = 100;
extern int          x42 = 100;
extern int          p = 20;
extern double       sl = 500;
extern int          pass = 1;
extern double       lots = 0.1;
extern int          mn = 888;
static int          prevtime = 0;


int init() {
   prevtime = Time[0];
   return(0);
}

//+------------------------------------------------------------------+
//| expert start function                                            |
//+------------------------------------------------------------------+
int start()
  {
   if (Time[0] == prevtime) return(0);
   prevtime = Time[0];
   
   if (! IsTradeAllowed()) {
      again();
      return(0);
   }
//----
   int total = OrdersTotal();
   for (int i = 0; i < total; i++) {
      OrderSelect(i, SELECT_BY_POS, MODE_TRADES);
      if ((OrderSymbol() == Symbol()) && (OrderMagicNumber() == mn)) {
         return(0);
      } 
   }
   
   
   int ticket = -1;
   
   RefreshRates();
   
   if (Supervisor() == 0) {
      return(0);
   }
   if (Supervisor() > 0) {
      ticket = OrderSend(Symbol(), OP_BUY, lots, Ask, 1, Bid - sl * Point, Bid + sl * Point, WindowExpertName(), mn, 0, Blue); 
      if (ticket < 0) {
         again();      
      }
   } else {
      ticket = OrderSend(Symbol(), OP_SELL, lots, Bid, 1, Ask + sl * Point, Ask - sl * Point, WindowExpertName(), mn, 0, Red); 
      if (ticket < 0) {
         again();
      }
   }
//-- Exit --
   return(0);
}
//+--------------------------- Supervisor ----------------------------------+


int Supervisor() {
   if (pass == 1) {
      return (perceptron1());
   }
   if (pass == 2) {
      return (perceptron2());
   }
   if ((pass == 3) || (! IsTesting())) {
      if (perceptron1() == perceptron2()) {
         return (perceptron1());
      }
   }
   return (0);
}



int perceptron1()   {
   double       w1 = x11 - 100;
   double       w2 = x21 - 100;
   double       w3 = x31 - 100;
   double       w4 = x41 - 100;
   double a1 = Close[0] - Open[p];
   double a2 = Open[p] - Open[p * 2];
   double a3 = Open[p * 2] - Open[p * 3];
   double a4 = Open[p * 3] - Open[p * 4];
   double result = w1 * a1 + w2 * a2 + w3 * a3 + w4 * a4;
   if (result > 0.0) {
      return (1);
   }
   return (-1);
}

int perceptron2()   {
   double       w1 = x12 - 100;
   double       w2 = x22 - 100;
   double       w3 = x32 - 100;
   double       w4 = x42 - 100;
   double a1 = Close[0] - Open[p];
   double a2 = Open[p] - Open[p * 2];
   double a3 = Open[p * 2] - Open[p * 3];
   double a4 = Open[p * 3] - Open[p * 4];
   double result = w1 * a1 + w2 * a2 + w3 * a3 + w4 * a4;
   if (result > 0.0) {
      return (1);
   }
   return (-1);
}



void again() {
   prevtime = Time[1];
   Sleep(30000);
}

